@@ -249,7 +249,7 @@ def build_turns_dataframe(calls_dict):
                 "asr_provider": conversation.get("asr_provider"),
                 "language": turn.get("language_code"),
                 "prediction": prediction,
-                "entities": entities
+                "predicted_entities": entities
             }
             flat_turns.append(turn_)
             turns.append(turn_)
